/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 2011-2014 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include "LiMason.H"
#include "phasePair.H"
#include "addToRunTimeSelectionTable.H"

// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //

namespace Foam
{
namespace heatTransferModels
{
    defineTypeNameAndDebug(LiMason, 0);
    addToRunTimeSelectionTable(heatTransferModel, LiMason, dictionary);
}
}


// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

Foam::heatTransferModels::LiMason::LiMason
(
    const dictionary& dict,
    const phasePair& pair
)
:
    heatTransferModel(dict, pair)
{}


// * * * * * * * * * * * * * * * * Destructor  * * * * * * * * * * * * * * * //

Foam::heatTransferModels::LiMason::~LiMason()
{}


// * * * * * * * * * * * * * * * Member Functions  * * * * * * * * * * * * * //

Foam::tmp<Foam::volScalarField>
Foam::heatTransferModels::LiMason::K() const
{
volScalarField Nu = neg(pair_.Re() - 200.0)*(scalar(2.0) + 0.6*pow(pair_.phase1(), 3.5)*sqrt(pair_.Re())*pow(pair_.Pr(), 1.0/3.0)) + pos(pair_.Re() - 200.0)*neg(pair_.Re() - 1500.0)*(scalar(2.0) + pow(pair_.phase1(), 3.5)*pow(pair_.Pr(), 1.0/3.0)*(0.5*sqrt(pair_.Re()) + 0.02*pow(pair_.Re(), 0.8))) + pos(pair_.Re() - 1500.0)*(scalar(2.0) + 0.000045*pow(pair_.phase1(), 3.5)*pow(pair_.Re(), 1.8));


    return
        6.0
       *max(pair_.dispersed(), residualAlpha_)
       *pair_.continuous().kappa()
       *Nu
       /sqr(pair_.dispersed().d());
}


// ************************************************************************* //
